=========
poisson_d
=========


.. image:: https://img.shields.io/pypi/v/poisson_d.svg
        :target: https://pypi.python.org/pypi/poisson_d

.. image:: https://img.shields.io/travis/iyunbo/poisson_d.svg
        :target: https://travis-ci.com/iyunbo/poisson_d

.. image:: https://readthedocs.org/projects/poisson_d/badge/?version=latest
        :target: https://poisson_d.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




poisson disk implementation in python


* Free software: MIT license
* Documentation: https://poisson_d.readthedocs.io.


Features
--------

* Generate poisson disk coordinates on a grid
* Generate points with charactoristics of poisson disk from an image
* Generate points with charactoristics of poisson disk from CMYK channels of an image

Credits
-------

This package was initialized with Cookiecutter_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
